summaryrefslogtreecommitdiffhomepage
path: root/test/e2e/shim-install.sh
diff options
context:
space:
mode:
Diffstat (limited to 'test/e2e/shim-install.sh')
-rwxr-xr-xtest/e2e/shim-install.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/test/e2e/shim-install.sh b/test/e2e/shim-install.sh
index c0252bdd4..f98455d46 100755
--- a/test/e2e/shim-install.sh
+++ b/test/e2e/shim-install.sh
@@ -7,8 +7,8 @@ set -ex
# Build gvisor-containerd-shim
if [ "${INSTALL_LATEST}" == "1" ]; then
{ # Step 1(release): Install gvisor-containerd-shim
-LATEST_RELEASE=$(wget -qO - https://api.github.com/repos/google/gvisor-containerd-shim/releases | grep -oP '(?<="browser_download_url": ")https://[^"]*' | head -1)
-wget -O gvisor-containerd-shim
+LATEST_RELEASE=$(wget -qO - https://api.github.com/repos/google/gvisor-containerd-shim/releases | grep -oP '(?<="browser_download_url": ")https://[^"]*gvisor-containerd-shim.linux-amd64' | head -1)
+wget -O gvisor-containerd-shim ${LATEST_RELEASE}
chmod +x gvisor-containerd-shim
sudo mv gvisor-containerd-shim /usr/local/bin/gvisor-containerd-shim
}
@@ -19,8 +19,8 @@ else
}
fi
-{ # Step 2: Create the gvisor-containerd-shim.yaml
-cat <<EOF | sudo tee /etc/containerd/gvisor-containerd-shim.yaml
+{ # Step 2: Create the gvisor-containerd-shim.toml
+cat <<EOF | sudo tee /etc/containerd/gvisor-containerd-shim.toml
# This is the path to the default runc containerd-shim.
runc_shim = "/usr/local/bin/containerd-shim"
EOF